==> aws-sdk-cpp-1.9.136-1-x86_64.pkg.tar.zst: usr/include/aws/compute-optimizer/model/ExportableVolumeField.h <==
﻿/**
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * SPDX-License-Identifier: Apache-2.0.
 */

#pragma once
#include <aws/compute-optimizer/ComputeOptimizer_EXPORTS.h>
#include <aws/core/utils/memory/stl/AWSString.h>

namespace Aws
{
namespace ComputeOptimizer
{
namespace Model
{
  enum class ExportableVolumeField
  {
    NOT_SET,
    AccountId,
    VolumeArn,
    Finding,
    UtilizationMetricsVolumeReadOpsPerSecondMaximum,
    UtilizationMetricsVolumeWriteOpsPerSecondMaximum,
    UtilizationMetricsVolumeReadBytesPerSecondMaximum,
    UtilizationMetricsVolumeWriteBytesPerSecondMaximum,
    LookbackPeriodInDays,
    CurrentConfigurationVolumeType,
    CurrentConfigurationVolumeBaselineIOPS,
    CurrentConfigurationVolumeBaselineThroughput,
    CurrentConfigurationVolumeBurstIOPS,
    CurrentConfigurationVolumeBurstThroughput,
    CurrentConfigurationVolumeSize,
    CurrentMonthlyPrice,
    RecommendationOptionsConfigurationVolumeType,
    RecommendationOptionsConfigurationVolumeBaselineIOPS,
    RecommendationOptionsConfigurationVolumeBaselineThroughput,
    RecommendationOptionsConfigurationVolumeBurstIOPS,
    RecommendationOptionsConfigurationVolumeBurstThroughput,
    RecommendationOptionsConfigurationVolumeSize,
    RecommendationOptionsMonthlyPrice,
    RecommendationOptionsPerformanceRisk,
    LastRefreshTimestamp
  };

namespace ExportableVolumeFieldMapper
{
AWS_COMPUTEOPTIMIZER_API ExportableVolumeField GetExportableVolumeFieldForName(const Aws::String& name);

AWS_COMPUTEOPTIMIZER_API Aws::String GetNameForExportableVolumeField(ExportableVolumeField value);
} // namespace ExportableVolumeFieldMapper
} // namespace Model
} // namespace ComputeOptimizer
} // namespace Aws

==> aws-sdk-cpp-1.11.124-1.1-x86_64.pkg.tar.zst: usr/include/aws/compute-optimizer/model/ExportableVolumeField.h <==
﻿/**
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * SPDX-License-Identifier: Apache-2.0.
 */

#pragma once
#include <aws/compute-optimizer/ComputeOptimizer_EXPORTS.h>
#include <aws/core/utils/memory/stl/AWSString.h>

namespace Aws
{
namespace ComputeOptimizer
{
namespace Model
{
  enum class ExportableVolumeField
  {
    NOT_SET,
    AccountId,
    VolumeArn,
    Finding,
    UtilizationMetricsVolumeReadOpsPerSecondMaximum,
    UtilizationMetricsVolumeWriteOpsPerSecondMaximum,
    UtilizationMetricsVolumeReadBytesPerSecondMaximum,
    UtilizationMetricsVolumeWriteBytesPerSecondMaximum,
    LookbackPeriodInDays,
    CurrentConfigurationVolumeType,
    CurrentConfigurationVolumeBaselineIOPS,
    CurrentConfigurationVolumeBaselineThroughput,
    CurrentConfigurationVolumeBurstIOPS,
    CurrentConfigurationVolumeBurstThroughput,
    CurrentConfigurationVolumeSize,
    CurrentMonthlyPrice,
    RecommendationOptionsConfigurationVolumeType,
    RecommendationOptionsConfigurationVolumeBaselineIOPS,
    RecommendationOptionsConfigurationVolumeBaselineThroughput,
    RecommendationOptionsConfigurationVolumeBurstIOPS,
    RecommendationOptionsConfigurationVolumeBurstThroughput,
    RecommendationOptionsConfigurationVolumeSize,
    RecommendationOptionsMonthlyPrice,
    RecommendationOptionsPerformanceRisk,
    LastRefreshTimestamp,
    CurrentPerformanceRisk,
    RecommendationOptionsSavingsOpportunityPercentage,
    RecommendationOptionsEstimatedMonthlySavingsCurrency,
    RecommendationOptionsEstimatedMonthlySavingsValue,
    RootVolume,
    Tags
  };

namespace ExportableVolumeFieldMapper
{
AWS_COMPUTEOPTIMIZER_API ExportableVolumeField GetExportableVolumeFieldForName(const Aws::String& name);

AWS_COMPUTEOPTIMIZER_API Aws::String GetNameForExportableVolumeField(ExportableVolumeField value);
} // namespace ExportableVolumeFieldMapper
} // namespace Model
} // namespace ComputeOptimizer
} // namespace Aws
